@@ -1,5 +1,5 @@
 from __future__ import absolute_import
 
 from .summary import *
-from lineage import *
+from .lineage import *
 from .base import *
